==> data_migration_report-1.0.0.tar.gz: data_migration_report/README.md <==
# Data Migration Report

The "Data Migration Report" module is designed to streamline and enhance the
data migration process in Drupal. By using this module, developers and
administrators can ensure data integrity, trace mapping issues, and gain
insights into the migration process, ultimately leading to smoother transitions
and better data management.

## FEATURES

This module provides two powerful Drush commands that facilitate the generation
of comprehensive content mapping YAML files and enable detailed testing and
reporting of migration data.

1. **Generate Content Mapping YAML:**
   - **Command:** `drush generate:content-mapping`
   - **Description:** This command creates a YAML file that maps source data
     fields to Drupal content fields. It helps in visualizing how data from the
     source system corresponds to Drupal’s fields and is essential for
     configuring migration processes.

2. **Test Data and Generate Report:**
   - **Command:** `drush migration:test`
   - **Description:** This command runs a test migration based on the provided
     mapping and generates a detailed report. The report includes data
     validation results, any issues encountered, and a summary of successfully
     migrated data. This helps in identifying and addressing potential problems
     before executing a full migration.
   - **Arguments:**
     - `entity_type` - The type of the content entity being migrated.
     - `bundle` - The bundle of the content entity.
   - **Options:**
     - `--limit` - Number of items to process.

## REQUIREMENTS

This module requires no modules outside of Drupal core.

## INSTALLATION

### Using the Drupal User Interface (easy):

1. Navigate to the 'Extend' page (admin/modules) via the manage administrative
   menu.
2. Locate the Data Migration Report module and select the checkbox next to
   it.
3. Click on 'Install' to enable the Data Migration Report module.

### Or use the command line (advanced, but very efficient).

- To enable Data Migration Report module with Drush, execute the command
  below: <br> `drush en data_migration_report`

## CONFIGURATION
Define the source database connection with the key '**migrate**' in addition to
the 'default' database connection in settings.php:

**OR**

Configure the source database connection at
`/admin/config/system/migrate-database-credentials`.

## MAINTAINERS

- Vishal Kadam (vishal.kadam) - https://www.drupal.org/user/3622517

==> data_migration_report-1.0.1.tar.gz: data_migration_report/README.md <==
# Data Migration Report

The Data Migration Report module is created to simplify and improve the data
migration process from Drupal 7 to Drupal 10 and later versions. By using this
module, developers and administrators can ensure data integrity, trace mapping
issues, and gain insights into the migration process, ultimately leading to
smoother transitions and better data management.

## FEATURES

This module provides two powerful Drush commands that facilitate the generation
of comprehensive content mapping YAML files and enable detailed testing and
reporting of migration data.

1. **Generate Content Mapping YAML:**
   - **Command:** `drush generate:content-mapping`
   - **Description:** This command creates a YAML file that maps source data
     fields to Drupal content fields. It helps in visualizing how data from the
     source system corresponds to Drupal’s fields and is essential for
     configuring migration processes.

2. **Test Data and Generate Report:**
   - **Command:** `drush migration:test`
   - **Description:** This command runs a test migration based on the provided
     mapping and generates a detailed report. The report includes data
     validation results, any issues encountered, and a summary of successfully
     migrated data. This helps in identifying and addressing potential problems
     before executing a full migration.
   - **Arguments:**
     - `entity_type` - The type of the content entity being migrated.
     - `bundle` - The bundle of the content entity.
   - **Options:**
     - `--limit` - Number of items to process.
     - `--ids` - List of source content ids to process.

## REQUIREMENTS

This module requires no modules outside of Drupal core.

## INSTALLATION

### Using the Drupal User Interface (easy):

1. Navigate to the 'Extend' page (admin/modules) via the manage administrative
   menu.
2. Locate the Data Migration Report module and select the checkbox next to
   it.
3. Click on 'Install' to enable the Data Migration Report module.

### Or use the command line (advanced, but very efficient).

- To enable Data Migration Report module with Drush, execute the command
  below: <br> `drush en data_migration_report`

## CONFIGURATION
Define the source database connection with the key '**migrate**' in addition to
the 'default' database connection in settings.php:

**OR**

Configure the source database connection at
`/admin/config/system/migrate-database-credentials`.

## MAINTAINERS

- Vishal Kadam (vishal.kadam) - https://www.drupal.org/user/3622517
